@@ -4,11 +4,12 @@ package JSON::Schema::Draft201909::Document;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: One JSON Schema document
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
+no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 use Mojo::URL;
 use Carp 'croak';
 use List::Util 1.29 'pairs';
@@ -20,7 +21,7 @@ use MooX::HandlesVia;
 use Types::Standard qw(InstanceOf HashRef Str Dict ArrayRef);
 use namespace::clean;
 
-extends 'Mojo::JSON::Pointer';
+extends 'Mojo::JSON::Pointer', 'Moo::Object';
 
 has schema => (
   is => 'ro',
@@ -75,14 +76,6 @@ has _serialized_schema => (
   init_arg => undef,
 );
 
-has _evaluator => (
-  is => 'ro',
-  isa => InstanceOf['JSON::Schema::Draft201909'],
-  weak_ref => 1,
-  lazy => 1,
-  default => sub { JSON::Schema::Draft201909->new },
-);
-
 has errors => (
   is => 'bare',
   handles_via => 'Array',
@@ -96,7 +89,7 @@ has errors => (
   default => sub { [] },
 );
 
-has evaluator_configs => (
+has evaluation_configs => (
   is => 'rwp',
   isa => HashRef,
   default => sub { {} },
@@ -126,13 +119,30 @@ around _add_resources => sub {
 sub data { goto \&schema }
 sub FOREIGNBUILDARGS { () }
 
+# for JSON serializers
+sub TO_JSON { goto \&schema }
+
+around BUILDARGS => sub {
+  my ($orig, $class, @args) = @_;
+
+  my $args = $class->$orig(@args);
+
+  # evaluator is only needed for traversal in BUILD; a different evaluator may be used for
+  # the actual evaluation.
+  croak '_evaluator is not a JSON::Schema::Draft201909'
+    if exists $args->{_evaluator} and not $args->{_evaluator}->$_isa('JSON::Schema::Draft201909');
+
+  $args->{_evaluator} //= JSON::Schema::Draft201909->new;
+  return $args;
+};
+
 sub BUILD {
-  my $self = shift;
+  my ($self, $args) = @_;
 
   croak 'canonical_uri cannot contain a fragment' if defined $self->canonical_uri->fragment;
 
   my $original_uri = $self->canonical_uri->clone;
-  my $state = $self->_evaluator->traverse($self->schema,
+  my $state = $args->{_evaluator}->traverse($self->schema,
     { canonical_schema_uri => $self->canonical_uri->clone });
 
   $self->_set_canonical_uri($state->{canonical_schema_uri});
@@ -150,7 +160,7 @@ sub BUILD {
   $self->_add_resources(@{$state->{identifiers}});
 
   # overlay the resulting configs with those that were provided by the caller
-  $self->_set_evaluator_configs(+{ %{$state->{configs}}, %{$self->evaluator_configs} });
+  $self->_set_evaluation_configs(+{ %{$state->{configs}}, %{$self->evaluation_configs} });
 }
 
 1;
@@ -169,7 +179,7 @@ JSON::Schema::Draft201909::Document - One JSON Schema document
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -221,7 +231,7 @@ A list of L<JSON::Schema::Draft201909::Error> objects that resulted when the sch
 originally parsed. (If a syntax error occurred, usually there will be just one error, as parse
 errors halt the parsing process.) Documents with errors cannot be evaluated.
 
-=head2 evaluator_configs
+=head2 evaluation_configs
 
 An optional hashref of configuration values that will be provided to the evaluator during
 evaluation of this document. See the third parameter of L<JSON::Schema::Draft201909/evaluate>.
@@ -231,7 +241,7 @@ override anything you have already explicitly set.
 
 =head1 METHODS
 
-=for Pod::Coverage BUILD FOREIGNBUILDARGS
+=for Pod::Coverage FOREIGNBUILDARGS BUILDARGS BUILD
 
 =head2 path_to_canonical_uri
 
@@ -251,6 +261,10 @@ See L<Mojo::JSON::Pointer/contains>.
 Extract value from L</"schema"> identified by the given JSON Pointer.
 See L<Mojo::JSON::Pointer/get>.
 
+=head2 TO_JSON
+
+Returns a data structure suitable for serialization. See L</schema>.
+
 =head1 SUPPORT
 
 Bugs may be submitted through L<https://github.com/karenetheridge/JSON-Schema-Draft201909/issues>.
