@@ -4,16 +4,17 @@ package JSON::Schema::Draft201909::Utilities;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Internal utilities for JSON::Schema::Draft201909
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
+no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 use B;
 use Carp 'croak';
 use JSON::MaybeXS 1.004001 'is_bool';
 use Ref::Util 0.100 qw(is_ref is_plain_arrayref is_plain_hashref);
-use Syntax::Keyword::Try 0.11;
+use Feature::Compat::Try;
 use Storable 'dclone';
 use strictures 2;
 use JSON::Schema::Draft201909::Error;
@@ -238,7 +239,7 @@ sub assert_keyword_type {
 sub assert_pattern {
   my ($state, $pattern) = @_;
   try { qr/$pattern/; }
-  catch { return E($state, $@); };
+  catch ($e) { return E($state, $e); };
   return 1;
 }
 
@@ -275,7 +276,7 @@ JSON::Schema::Draft201909::Utilities - Internal utilities for JSON::Schema::Draf
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
