@@ -4,31 +4,28 @@ package JSON::Schema::Draft201909::Vocabulary;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Base role for JSON Schema vocabulary classes
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
-use Ref::Util 0.100 'is_ref';
-use JSON::Schema::Draft201909::Utilities qw(jsonp A assert_keyword_type);
+no if "$]" >= 5.033006, feature => 'bareword_filehandles';
+use JSON::Schema::Draft201909::Utilities qw(jsonp assert_keyword_type);
 use Moo::Role;
 use strictures 2;
-use Types::Standard 1.010002 'InstanceOf';
 use namespace::clean;
 
-has evaluator => (
-  is => 'ro',
-  isa => InstanceOf['JSON::Schema::Draft201909'],
-  required => 1,
-  weak_ref => 1,
-);
-
 requires qw(vocabulary keywords);
 
+sub traverse {
+  my ($self, $schema, $state) = @_;
+  $state->{evaluator}->_traverse($schema, $state);
+}
+
 sub traverse_schema {
   my ($self, $schema, $state) = @_;
 
-  $self->evaluator->_traverse($schema->{$state->{keyword}},
+  $state->{evaluator}->_traverse($schema->{$state->{keyword}},
     +{ %$state, schema_path => $state->{schema_path}.'/'.$state->{keyword} });
 }
 
@@ -39,7 +36,7 @@ sub traverse_array_schemas {
   return E($state, '"%s" array is empty') if not @{$schema->{$state->{keyword}}};
 
   foreach my $idx (0 .. $#{$schema->{$state->{keyword}}}) {
-    $self->evaluator->_traverse($schema->{$state->{keyword}}[$idx],
+    $state->{evaluator}->_traverse($schema->{$state->{keyword}}[$idx],
       +{ %$state, schema_path => $state->{schema_path}.'/'.$state->{keyword}.'/'.$idx });
   }
 }
@@ -50,11 +47,16 @@ sub traverse_object_schemas {
   return if not assert_keyword_type($state, $schema, 'object');
 
   foreach my $property (sort keys %{$schema->{$state->{keyword}}}) {
-    $self->evaluator->_traverse($schema->{$state->{keyword}}{$property},
+    $state->{evaluator}->_traverse($schema->{$state->{keyword}}{$property},
       +{ %$state, schema_path => jsonp($state->{schema_path}, $state->{keyword}, $property) });
   }
 }
 
+sub eval {
+  my ($self, $data, $schema, $state) = @_;
+  $state->{evaluator}->_eval($data, $schema, $state);
+}
+
 1;
 
 __END__
@@ -69,7 +71,7 @@ JSON::Schema::Draft201909::Vocabulary - Base role for JSON Schema vocabulary cla
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -86,11 +88,6 @@ User-defined custom vocabularies are not supported at this time.
 
 =head1 ATTRIBUTES
 
-=head2 evaluator
-
-The L<JSON::Schema::Draft201909> evaluator object, used for implementing C<_traverse_keyword_*> and
-C<_eval_keyword_*>.
-
 =head1 METHODS
 
 =for stopwords schema subschema
@@ -104,6 +101,10 @@ L<JSON Schema Core Meta-specification, section 8.1.2|https://json-schema.org/dra
 
 The list of keywords defined by the vocabulary. Must be implemented by the composing class.
 
+=head2 traverse
+
+Traverses a subschema.
+
 =head2 traverse_schema
 
 Recursively traverses the schema at the current keyword.
@@ -116,6 +117,10 @@ Recursively traverses the list of subschemas at the current keyword.
 
 Recursively traverses the (subschema) values of the object at the current keyword.
 
+=head2 eval
+
+Evaluates a subschema.
+
 =head1 SUPPORT
 
 Bugs may be submitted through L<https://github.com/karenetheridge/JSON-Schema-Draft201909/issues>.
