@@ -4,11 +4,12 @@ package JSON::Schema::Draft201909::Vocabulary::Content;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Draft 2019-09 Content vocabulary
 
-our $VERSION = '0.020';
+our $VERSION = '0.021';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
+no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 use Storable 'dclone';
 use JSON::Schema::Draft201909::Utilities qw(is_type A assert_keyword_type);
 use Moo;
@@ -46,8 +47,7 @@ sub _traverse_keyword_contentSchema {
 
   # since contentSchema should never be evaluated in the context of the containing schema, it is
   # not appropriate to gather identifiers found therein -- but we can still validate the subschema.
-  $self->evaluator->_traverse($schema->{contentSchema},
-    +{ %$state, identifiers => [], schema_path => $state->{schema_path}.'/contentSchema' });
+  $self->traverse_schema($schema, +{ %$state, identifiers => [] });
 }
 
 sub _eval_keyword_contentSchema {
@@ -73,7 +73,7 @@ JSON::Schema::Draft201909::Vocabulary::Content - Implementation of the JSON Sche
 
 =head1 VERSION
 
-version 0.020
+version 0.021
 
 =head1 DESCRIPTION
 
